| predict.spectral | R Documentation |
spectral objectObtain predicted density ratio values from a spectral object
## S3 method for class 'spectral'
predict(
object,
newdata = NULL,
sigma = c("sigmaopt", "all"),
m = c("opt", "all"),
...
)
object |
A |
newdata |
Optional |
sigma |
A scalar with the Gaussian kernel width |
m |
integer indicating the dimension of the eigenvector expansion |
... |
Additional arguments to be passed to the function |
An array with predicted density ratio values from possibly new data, but otherwise the numerator samples.
predict, spectral
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.